==> qtjambi-qt3drender-5.15.13-sources.jar: io/qt/qt3d/render/QTexture2DArray.java <==
package io.qt.qt3d.render;


/**
 * <p>A QAbstractTexture with a Target2DArray target format</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3drender-qtexture2darray.html">Qt3DRender::QTexture2DArray</a></p>
 */
public class QTexture2DArray extends io.qt.qt3d.render.QAbstractTexture
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QTexture2DArray.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QTexture2DArray(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QTexture2DArray() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qtexture2darray.html#QTexture2DArray">Qt3DRender::QTexture2DArray::QTexture2DArray(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QTexture2DArray(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QTexture2DArray instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QTexture2DArray(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QTexture2DArray(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QTexture2DArray instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3drender-6.2.1-sources.jar: io/qt/qt3d/render/QTexture2DArray.java <==
package io.qt.qt3d.render;


/**
 * <p>A QAbstractTexture with a Target2DArray target format</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qt3drender-qtexture2darray.html">Qt3DRender::QTexture2DArray</a></p>
 */
public class QTexture2DArray extends io.qt.qt3d.render.QAbstractTexture
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QTexture2DArray.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QTexture2DArray(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QTexture2DArray() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qtexture2darray.html#QTexture2DArray">Qt3DRender::QTexture2DArray::QTexture2DArray(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QTexture2DArray(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QTexture2DArray instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QTexture2DArray(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QTexture2DArray(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QTexture2DArray instance, QDeclarativeConstructor constructor);
    
}
